Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(431)

Unified Diff: remoting/host/desktop_session_win.h

Issue 12545006: The worker process launcher can now ask the worker to crash. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/desktop_session_win.h
diff --git a/remoting/host/desktop_session_win.h b/remoting/host/desktop_session_win.h
index 8ca7f1be0bee10f8e8d754761ff73fa2cb0f26a1..221a44cffdd27f670ad4b5c892973d6c0ad5fe9e 100644
--- a/remoting/host/desktop_session_win.h
+++ b/remoting/host/desktop_session_win.h
@@ -64,8 +64,8 @@ class DesktopSessionWin
// ChromotingDesktopDaemonMsg_InjectSas handler.
void OnInjectSas();
- // Restarts the desktop process.
- void RestartDesktopProcess(const tracked_objects::Location& location);
+ // Requests the desktop process to crash.
+ void CrashDesktopProcess(const tracked_objects::Location& location);
// Task runner on which public methods of this class should be called.
scoped_refptr<AutoThreadTaskRunner> main_task_runner_;

Powered by Google App Engine
This is Rietveld 408576698